pub struct initializeReturn {}Expand description
Derives so the built call can be compared and printed by the
initializer that assembles it.
Container type for the return parameters of the initialize(address,address,address,bytes32) function.