pub enum HandleResolverEvents {
UrlsChanged(UrlsChanged),
SignerChanged(SignerChanged),
}Expand description
Container for all the HandleResolver events.
Variants
UrlsChanged(UrlsChanged)
SignerChanged(SignerChanged)
Implementations
Sourceimpl HandleResolverEvents
impl HandleResolverEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl HandleResolverEvents
impl HandleResolverEvents
Sourcepub fn urls_changed(urls: Vec<String>) -> Self
pub fn urls_changed(urls: Vec<String>) -> Self
Creates a UrlsChanged event.
event UrlsChanged(string[])Sourcepub fn signer_changed(signer: Address, trusted: bool) -> Self
pub fn signer_changed(signer: Address, trusted: bool) -> Self
Creates a SignerChanged event.
event SignerChanged(address,bool)Trait Implementations
Sourceimpl Clone for HandleResolverEvents
impl Clone for HandleResolverEvents
Sourceimpl IntoLogData for HandleResolverEvents
impl IntoLogData for HandleResolverEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl SolEventInterface for HandleResolverEvents
impl SolEventInterface for HandleResolverEvents