pub struct HandleResolverInstance<P, N = Ethereum> { /* private fields */ }Expand description
A HandleResolver instance.
Contains type-safe methods for interacting with an on-chain instance of the
HandleResolver contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> HandleResolverInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> HandleResolverInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain HandleResolver contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> HandleResolverInstance<&P, N>
impl<P: Clone, N> HandleResolverInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> HandleResolverInstance<P, N>
pub fn with_cloned_provider(self) -> HandleResolverInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> HandleResolverInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> HandleResolverInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn urls(&self, index: U256) -> SolCallBuilder<&P, urlsCall, N>
pub fn urls(&self, index: U256) -> SolCallBuilder<&P, urlsCall, N>
Creates a new call builder for the [urls] function.
Sourcepub fn urlCount(&self) -> SolCallBuilder<&P, urlCountCall, N>
pub fn urlCount(&self) -> SolCallBuilder<&P, urlCountCall, N>
Creates a new call builder for the [urlCount] function.
Sourcepub fn signers(&self, signer: Address) -> SolCallBuilder<&P, signersCall, N>
pub fn signers(&self, signer: Address) -> SolCallBuilder<&P, signersCall, N>
Creates a new call builder for the [signers] function.
Sourcepub fn MAX_LIFETIME(&self) -> SolCallBuilder<&P, MAX_LIFETIMECall, N>
pub fn MAX_LIFETIME(&self) -> SolCallBuilder<&P, MAX_LIFETIMECall, N>
Creates a new call builder for the [MAX_LIFETIME] function.
Sourcepub fn makeSignatureHash(
&self,
target: Address,
expires: u64,
request: Bytes,
result: Bytes,
) -> SolCallBuilder<&P, makeSignatureHashCall, N>
pub fn makeSignatureHash( &self, target: Address, expires: u64, request: Bytes, result: Bytes, ) -> SolCallBuilder<&P, makeSignatureHashCall, N>
Creates a new call builder for the [makeSignatureHash] function.
Sourcepub fn resolveWithProof(
&self,
response: Bytes,
extraData: Bytes,
) -> SolCallBuilder<&P, resolveWithProofCall, N>
pub fn resolveWithProof( &self, response: Bytes, extraData: Bytes, ) -> SolCallBuilder<&P, resolveWithProofCall, N>
Creates a new call builder for the [resolveWithProof] function.
Sourcepub fn supportsInterface(
&self,
interfaceId: FixedBytes<4>,
) -> SolCallBuilder<&P, supportsInterfaceCall, N>
pub fn supportsInterface( &self, interfaceId: FixedBytes<4>, ) -> SolCallBuilder<&P, supportsInterfaceCall, N>
Creates a new call builder for the [supportsInterface] function.
Sourcepub fn setUrls(&self, urls_: Vec<String>) -> SolCallBuilder<&P, setUrlsCall, N>
pub fn setUrls(&self, urls_: Vec<String>) -> SolCallBuilder<&P, setUrlsCall, N>
Creates a new call builder for the [setUrls] function.
Sourcepub fn setSigner(
&self,
signer: Address,
trusted: bool,
) -> SolCallBuilder<&P, setSignerCall, N>
pub fn setSigner( &self, signer: Address, trusted: bool, ) -> SolCallBuilder<&P, setSignerCall, N>
Creates a new call builder for the [setSigner] function.
Sourcepub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
pub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
Creates a new call builder for the [owner] function.
Sourcepub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
pub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
Creates a new call builder for the [pendingOwner] function.
Sourcepub fn transferOwnership(
&self,
newOwner: Address,
) -> SolCallBuilder<&P, transferOwnershipCall, N>
pub fn transferOwnership( &self, newOwner: Address, ) -> SolCallBuilder<&P, transferOwnershipCall, N>
Creates a new call builder for the [transferOwnership] function.
Sourcepub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
pub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
Creates a new call builder for the [acceptOwnership] function.
Sourceimpl<P: Provider<N>, N: Network> HandleResolverInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> HandleResolverInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn UrlsChanged_filter(&self) -> Event<&P, UrlsChanged, N>
pub fn UrlsChanged_filter(&self) -> Event<&P, UrlsChanged, N>
Creates a new event filter for the UrlsChanged event.
Sourcepub fn SignerChanged_filter(&self) -> Event<&P, SignerChanged, N>
pub fn SignerChanged_filter(&self) -> Event<&P, SignerChanged, N>
Creates a new event filter for the SignerChanged event.