pub struct HandleEscrowInstance<P, N = Ethereum> { /* private fields */ }Expand description
A HandleEscrow instance.
Contains type-safe methods for interacting with an on-chain instance of the
HandleEscrow contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> HandleEscrowInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> HandleEscrowInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain HandleEscrow contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> HandleEscrowInstance<&P, N>
impl<P: Clone, N> HandleEscrowInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> HandleEscrowInstance<P, N>
pub fn with_cloned_provider(self) -> HandleEscrowInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> HandleEscrowInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> HandleEscrowInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn initialize(
&self,
owner_: Address,
registry_: Address,
) -> SolCallBuilder<&P, initializeCall, N>
pub fn initialize( &self, owner_: Address, registry_: Address, ) -> SolCallBuilder<&P, initializeCall, N>
Creates a new call builder for the [initialize] function.
Sourcepub fn deposit(
&self,
platformId: FixedBytes<32>,
handleHash: FixedBytes<32>,
token: Address,
amount: U256,
refundTo: Address,
) -> SolCallBuilder<&P, depositCall, N>
pub fn deposit( &self, platformId: FixedBytes<32>, handleHash: FixedBytes<32>, token: Address, amount: U256, refundTo: Address, ) -> SolCallBuilder<&P, depositCall, N>
Creates a new call builder for the [deposit] function.
Sourcepub fn claim(
&self,
handleNode: FixedBytes<32>,
tokens: Vec<Address>,
recipient: Address,
) -> SolCallBuilder<&P, claimCall, N>
pub fn claim( &self, handleNode: FixedBytes<32>, tokens: Vec<Address>, recipient: Address, ) -> SolCallBuilder<&P, claimCall, N>
Creates a new call builder for the [claim] function.
Sourcepub fn refund(
&self,
handleNode: FixedBytes<32>,
token: Address,
recipient: Address,
) -> SolCallBuilder<&P, refundCall, N>
pub fn refund( &self, handleNode: FixedBytes<32>, token: Address, recipient: Address, ) -> SolCallBuilder<&P, refundCall, N>
Creates a new call builder for the [refund] function.
Sourcepub fn escrowed(
&self,
handleNode: FixedBytes<32>,
token: Address,
) -> SolCallBuilder<&P, escrowedCall, N>
pub fn escrowed( &self, handleNode: FixedBytes<32>, token: Address, ) -> SolCallBuilder<&P, escrowedCall, N>
Creates a new call builder for the [escrowed] function.
Sourcepub fn refundable(
&self,
handleNode: FixedBytes<32>,
token: Address,
refundTo: Address,
) -> SolCallBuilder<&P, refundableCall, N>
pub fn refundable( &self, handleNode: FixedBytes<32>, token: Address, refundTo: Address, ) -> SolCallBuilder<&P, refundableCall, N>
Creates a new call builder for the [refundable] function.
Sourcepub fn registry(&self) -> SolCallBuilder<&P, registryCall, N>
pub fn registry(&self) -> SolCallBuilder<&P, registryCall, N>
Creates a new call builder for the [registry] function.
Sourcepub fn NATIVE(&self) -> SolCallBuilder<&P, NATIVECall, N>
pub fn NATIVE(&self) -> SolCallBuilder<&P, NATIVECall, N>
Creates a new call builder for the [NATIVE] function.
Sourcepub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
pub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
Creates a new call builder for the [owner] function.
Sourcepub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
pub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
Creates a new call builder for the [pendingOwner] function.
Sourcepub fn transferOwnership(
&self,
newOwner: Address,
) -> SolCallBuilder<&P, transferOwnershipCall, N>
pub fn transferOwnership( &self, newOwner: Address, ) -> SolCallBuilder<&P, transferOwnershipCall, N>
Creates a new call builder for the [transferOwnership] function.
Sourcepub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
pub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
Creates a new call builder for the [acceptOwnership] function.
Sourcepub fn renounceOwnership(&self) -> SolCallBuilder<&P, renounceOwnershipCall, N>
pub fn renounceOwnership(&self) -> SolCallBuilder<&P, renounceOwnershipCall, N>
Creates a new call builder for the [renounceOwnership] function.
Sourceimpl<P: Provider<N>, N: Network> HandleEscrowInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> HandleEscrowInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn Deposited_filter(&self) -> Event<&P, Deposited, N>
pub fn Deposited_filter(&self) -> Event<&P, Deposited, N>
Creates a new event filter for the Deposited event.
Sourcepub fn Forwarded_filter(&self) -> Event<&P, Forwarded, N>
pub fn Forwarded_filter(&self) -> Event<&P, Forwarded, N>
Creates a new event filter for the Forwarded event.
Sourcepub fn Claimed_filter(&self) -> Event<&P, Claimed, N>
pub fn Claimed_filter(&self) -> Event<&P, Claimed, N>
Creates a new event filter for the Claimed event.
Sourcepub fn OwnershipTransferStarted_filter(
&self,
) -> Event<&P, OwnershipTransferStarted, N>
pub fn OwnershipTransferStarted_filter( &self, ) -> Event<&P, OwnershipTransferStarted, N>
Creates a new event filter for the OwnershipTransferStarted event.
Sourcepub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
pub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
Creates a new event filter for the OwnershipTransferred event.