pub struct LibidFactoryInstance<P, N = Ethereum> { /* private fields */ }Expand description
A LibidFactory instance.
Contains type-safe methods for interacting with an on-chain instance of the
LibidFactory contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> LibidFactoryInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> LibidFactoryInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain LibidFactory contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> LibidFactoryInstance<&P, N>
impl<P: Clone, N> LibidFactoryInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> LibidFactoryInstance<P, N>
pub fn with_cloned_provider(self) -> LibidFactoryInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> LibidFactoryInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> LibidFactoryInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn initialize(
&self,
owner_: Address,
) -> SolCallBuilder<&P, initializeCall, N>
pub fn initialize( &self, owner_: Address, ) -> SolCallBuilder<&P, initializeCall, N>
Creates a new call builder for the [initialize] function.
Sourcepub fn deploy_call(
&self,
name: String,
creationCode: Bytes,
) -> SolCallBuilder<&P, deployCall, N>
pub fn deploy_call( &self, name: String, creationCode: Bytes, ) -> SolCallBuilder<&P, deployCall, N>
Creates a new call builder for the [deploy_call] function.
Sourcepub fn predict(&self, name: String) -> SolCallBuilder<&P, predictCall, N>
pub fn predict(&self, name: String) -> SolCallBuilder<&P, predictCall, N>
Creates a new call builder for the [predict] function.
Sourcepub fn deployedAt(&self, name: String) -> SolCallBuilder<&P, deployedAtCall, N>
pub fn deployedAt(&self, name: String) -> SolCallBuilder<&P, deployedAtCall, N>
Creates a new call builder for the [deployedAt] function.
Sourcepub fn deployments(
&self,
nameHash: FixedBytes<32>,
) -> SolCallBuilder<&P, deploymentsCall, N>
pub fn deployments( &self, nameHash: FixedBytes<32>, ) -> SolCallBuilder<&P, deploymentsCall, N>
Creates a new call builder for the [deployments] function.
Sourcepub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
pub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
Creates a new call builder for the [owner] function.
Sourcepub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
pub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
Creates a new call builder for the [pendingOwner] function.
Sourcepub fn transferOwnership(
&self,
newOwner: Address,
) -> SolCallBuilder<&P, transferOwnershipCall, N>
pub fn transferOwnership( &self, newOwner: Address, ) -> SolCallBuilder<&P, transferOwnershipCall, N>
Creates a new call builder for the [transferOwnership] function.
Sourcepub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
pub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
Creates a new call builder for the [acceptOwnership] function.
Sourceimpl<P: Provider<N>, N: Network> LibidFactoryInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> LibidFactoryInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.