pub enum IdentityNamesEvents {
HandleRetired(HandleRetired),
PlatformConfigured(PlatformConfigured),
NameUnpublished(NameUnpublished),
}Expand description
Container for all the IdentityNames events.
Variants
HandleRetired(HandleRetired)
PlatformConfigured(PlatformConfigured)
NameUnpublished(NameUnpublished)
Implementations
Sourceimpl IdentityNamesEvents
impl IdentityNamesEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IdentityNamesEvents
impl IdentityNamesEvents
Sourcepub fn handle_retired(
platform_id: FixedBytes<32>,
handle_node: FixedBytes<32>,
owner: Address,
) -> Self
pub fn handle_retired( platform_id: FixedBytes<32>, handle_node: FixedBytes<32>, owner: Address, ) -> Self
Creates a HandleRetired event.
event HandleRetired(bytes32,bytes32,address)Sourcepub fn platform_configured(
platform_id: FixedBytes<32>,
verifier: Address,
) -> Self
pub fn platform_configured( platform_id: FixedBytes<32>, verifier: Address, ) -> Self
Creates a PlatformConfigured event.
event PlatformConfigured(bytes32,address)Sourcepub fn name_unpublished(owner: Address, platform_id: FixedBytes<32>) -> Self
pub fn name_unpublished(owner: Address, platform_id: FixedBytes<32>) -> Self
Creates a NameUnpublished event.
event NameUnpublished(address,bytes32)Trait Implementations
Sourceimpl Clone for IdentityNamesEvents
impl Clone for IdentityNamesEvents
Sourcefn clone(&self) -> IdentityNamesEvents
fn clone(&self) -> IdentityNamesEvents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl IntoLogData for IdentityNamesEvents
impl IntoLogData for IdentityNamesEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl SolEventInterface for IdentityNamesEvents
impl SolEventInterface for IdentityNamesEvents