pub struct IdentityNamesInstance<P, N = Ethereum> { /* private fields */ }Expand description
A IdentityNames instance.
Contains type-safe methods for interacting with an on-chain instance of the
IdentityNames contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> IdentityNamesInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> IdentityNamesInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain IdentityNames contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> IdentityNamesInstance<&P, N>
impl<P: Clone, N> IdentityNamesInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> IdentityNamesInstance<P, N>
pub fn with_cloned_provider(self) -> IdentityNamesInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> IdentityNamesInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> IdentityNamesInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn initialize(
&self,
owner_: Address,
) -> SolCallBuilder<&P, initializeCall, N>
pub fn initialize( &self, owner_: Address, ) -> SolCallBuilder<&P, initializeCall, N>
Creates a new call builder for the [initialize] function.
Sourcepub fn setPlatform(
&self,
platformId: FixedBytes<32>,
verifier: Address,
maxFutureObservation: u64,
rules: <Rules as SolType>::RustType,
) -> SolCallBuilder<&P, setPlatformCall, N>
pub fn setPlatform( &self, platformId: FixedBytes<32>, verifier: Address, maxFutureObservation: u64, rules: <Rules as SolType>::RustType, ) -> SolCallBuilder<&P, setPlatformCall, N>
Creates a new call builder for the [setPlatform] function.
Sourcepub fn verifierOf(
&self,
platformId: FixedBytes<32>,
) -> SolCallBuilder<&P, verifierOfCall, N>
pub fn verifierOf( &self, platformId: FixedBytes<32>, ) -> SolCallBuilder<&P, verifierOfCall, N>
Creates a new call builder for the [verifierOf] function.
Sourcepub fn bind(
&self,
platformId: FixedBytes<32>,
proof: Bytes,
publishName: bool,
) -> SolCallBuilder<&P, bindCall, N>
pub fn bind( &self, platformId: FixedBytes<32>, proof: Bytes, publishName: bool, ) -> SolCallBuilder<&P, bindCall, N>
Creates a new call builder for the [bind] function.
Sourcepub fn unpublish(
&self,
platformId: FixedBytes<32>,
) -> SolCallBuilder<&P, unpublishCall, N>
pub fn unpublish( &self, platformId: FixedBytes<32>, ) -> SolCallBuilder<&P, unpublishCall, N>
Creates a new call builder for the [unpublish] function.
Sourcepub fn resolveId(
&self,
platformId: FixedBytes<32>,
userId: String,
) -> SolCallBuilder<&P, resolveIdCall, N>
pub fn resolveId( &self, platformId: FixedBytes<32>, userId: String, ) -> SolCallBuilder<&P, resolveIdCall, N>
Creates a new call builder for the [resolveId] function.
Sourcepub fn resolveHandle(
&self,
platformId: FixedBytes<32>,
handle: String,
) -> SolCallBuilder<&P, resolveHandleCall, N>
pub fn resolveHandle( &self, platformId: FixedBytes<32>, handle: String, ) -> SolCallBuilder<&P, resolveHandleCall, N>
Creates a new call builder for the [resolveHandle] function.
Sourcepub fn resolvePair(
&self,
platformId: FixedBytes<32>,
handle: String,
userId: String,
) -> SolCallBuilder<&P, resolvePairCall, N>
pub fn resolvePair( &self, platformId: FixedBytes<32>, handle: String, userId: String, ) -> SolCallBuilder<&P, resolvePairCall, N>
Creates a new call builder for the [resolvePair] function.
Sourcepub fn reverseOf(
&self,
wallet: Address,
platformId: FixedBytes<32>,
) -> SolCallBuilder<&P, reverseOfCall, N>
pub fn reverseOf( &self, wallet: Address, platformId: FixedBytes<32>, ) -> SolCallBuilder<&P, reverseOfCall, N>
Creates a new call builder for the [reverseOf] function.
Sourcepub fn primaryOf(
&self,
wallet: Address,
platformId: FixedBytes<32>,
) -> SolCallBuilder<&P, primaryOfCall, N>
pub fn primaryOf( &self, wallet: Address, platformId: FixedBytes<32>, ) -> SolCallBuilder<&P, primaryOfCall, N>
Creates a new call builder for the [primaryOf] function.
Sourceimpl<P: Provider<N>, N: Network> IdentityNamesInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> IdentityNamesInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn HandleRetired_filter(&self) -> Event<&P, HandleRetired, N>
pub fn HandleRetired_filter(&self) -> Event<&P, HandleRetired, N>
Creates a new event filter for the HandleRetired event.
Sourcepub fn PlatformConfigured_filter(&self) -> Event<&P, PlatformConfigured, N>
pub fn PlatformConfigured_filter(&self) -> Event<&P, PlatformConfigured, N>
Creates a new event filter for the PlatformConfigured event.
Sourcepub fn NameUnpublished_filter(&self) -> Event<&P, NameUnpublished, N>
pub fn NameUnpublished_filter(&self) -> Event<&P, NameUnpublished, N>
Creates a new event filter for the NameUnpublished event.