pub struct bindAtVersionCall {
pub platformId: FixedBytes<32>,
pub version: u32,
pub proof: Bytes,
pub publishName: bool,
}Expand description
Function with signature bindAtVersion(bytes32,uint32,bytes,bool) and selector 0x58b9b1e7.
function bindAtVersion(bytes32 platformId, uint32 version, bytes calldata proof, bool publishName) external;Fields
platformId: FixedBytes<32>version: u32proof: BytespublishName: boolTrait Implementations
Sourceimpl Clone for bindAtVersionCall
impl Clone for bindAtVersionCall
Sourcefn clone(&self) -> bindAtVersionCall
fn clone(&self) -> bindAtVersionCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for bindAtVersionCall
impl SolCall for bindAtVersionCall
Sourceconst SIGNATURE: &'static str = "bindAtVersion(bytes32,uint32,bytes,bool)"
const SIGNATURE: &'static str = "bindAtVersion(bytes32,uint32,bytes,bool)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedBytes<32>, Uint<32>, Bytes, Bool)
type Parameters<'a> = (FixedBytes<32>, Uint<32>, Bytes, Bool)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<bindAtVersionCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<bindAtVersionCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = bindAtVersionReturn
type Return = bindAtVersionReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<bindAtVersionCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<bindAtVersionCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.