pub struct NotProofTarget {
pub proved: Address,
pub caller: Address,
}Expand description
Custom error with signature NotProofTarget(address,address) and selector 0x9b562d5e.
error NotProofTarget(address proved, address caller);Fields
proved: Addresscaller: AddressTrait Implementations
Sourceimpl Clone for NotProofTarget
impl Clone for NotProofTarget
Sourceimpl JsonAbiExt for NotProofTarget
impl JsonAbiExt for NotProofTarget
Sourceimpl SolError for NotProofTarget
impl SolError for NotProofTarget
Sourcetype Parameters<'a> = (Address, Address)
type Parameters<'a> = (Address, Address)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<NotProofTarget as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<NotProofTarget as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.