pub enum WalletFactoryEvents {
WalletCreated(WalletCreated),
WalletImplementationUpgraded(WalletImplementationUpgraded),
}Expand description
Container for all the WalletFactory events.
Variants
WalletCreated(WalletCreated)
WalletImplementationUpgraded(WalletImplementationUpgraded)
Implementations
Sourceimpl WalletFactoryEvents
impl WalletFactoryEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl WalletFactoryEvents
impl WalletFactoryEvents
Sourcepub fn wallet_created(wallet: Address, first_identity: FixedBytes<32>) -> Self
pub fn wallet_created(wallet: Address, first_identity: FixedBytes<32>) -> Self
Creates a WalletCreated event.
event WalletCreated(address,bytes32)Sourcepub fn wallet_implementation_upgraded(new_implementation: Address) -> Self
pub fn wallet_implementation_upgraded(new_implementation: Address) -> Self
Creates a WalletImplementationUpgraded event.
event WalletImplementationUpgraded(address)Trait Implementations
Sourceimpl Clone for WalletFactoryEvents
impl Clone for WalletFactoryEvents
Sourcefn clone(&self) -> WalletFactoryEvents
fn clone(&self) -> WalletFactoryEvents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl IntoLogData for WalletFactoryEvents
impl IntoLogData for WalletFactoryEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl SolEventInterface for WalletFactoryEvents
impl SolEventInterface for WalletFactoryEvents