WebWalletEvents

Enum WebWalletEvents 

pub enum WebWalletEvents {
    SessionRegistered(SessionRegistered),
    SessionRevoked(SessionRevoked),
    Executed(Executed),
    NativeReceived(NativeReceived),
    NativeSent(NativeSent),
}
Container for all the WebWallet events.

Variants



SessionRegistered(SessionRegistered)



SessionRevoked(SessionRevoked)



Executed(Executed)



NativeReceived(NativeReceived)



NativeSent(NativeSent)

Implementations

Source

impl WebWalletEvents

pub const SELECTORS: &'static [[u8; 32]]

All the selectors of this enum.

Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.

Prefer using SolInterface methods instead.

pub const VARIANT_NAMES: &'static [&'static str]

The names of the variants in the same order as SELECTORS.

pub const SIGNATURES: &'static [&'static str]

The signatures in the same order as SELECTORS.

pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>

Returns the signature for the given selector, if known.

pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>

Returns the enum variant name for the given selector, if known.

Source

impl WebWalletEvents

pub fn session_registered( platform: String, handle: String, session_addr: Address, ) -> Self

Creates a SessionRegistered event.

event SessionRegistered(string,string,address)
pub fn session_revoked( platform: String, handle: String, session_addr: Address, ) -> Self

Creates a SessionRevoked event.

event SessionRevoked(string,string,address)
pub fn executed(target: Address, value: U256, nonce: U256) -> Self

Creates a Executed event.

event Executed(address,uint256,uint256)
pub fn native_received(from: Address, amount: U256) -> Self

Creates a NativeReceived event.

event NativeReceived(address,uint256)
pub fn native_sent(to: Address, amount: U256) -> Self

Creates a NativeSent event.

event NativeSent(address,uint256)