WebWalletInstance

Struct WebWalletInstance 

pub struct WebWalletInstance<P, N = Ethereum> { /* private fields */ }
A WebWallet instance.

Contains type-safe methods for interacting with an on-chain instance of the WebWallet contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Implementations

Source

impl<P: Provider<N>, N: Network> WebWalletInstance<P, N>

Instantiation and getters/setters.

pub const fn new(address: Address, __provider: P) -> Self

Creates a new wrapper around an on-chain WebWallet contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> Self

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.

Source

impl<P: Clone, N> WebWalletInstance<&P, N>

pub fn with_cloned_provider(self) -> WebWalletInstance<P, N>

Clones the provider and returns a new instance with the cloned provider.

Source

impl<P: Provider<N>, N: Network> WebWalletInstance<P, N>

Function calls.

pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn threshold(&self) -> SolCallBuilder<&P, thresholdCall, N>

Creates a new call builder for the [threshold] function.

pub fn nonce(&self) -> SolCallBuilder<&P, nonceCall, N>

Creates a new call builder for the [nonce] function.

pub fn registry(&self) -> SolCallBuilder<&P, registryCall, N>

Creates a new call builder for the [registry] function.

pub fn factory(&self) -> SolCallBuilder<&P, factoryCall, N>

Creates a new call builder for the [factory] function.

pub fn identityCount(&self) -> SolCallBuilder<&P, identityCountCall, N>

Creates a new call builder for the [identityCount] function.

pub fn identityAt(&self, index: U256) -> SolCallBuilder<&P, identityAtCall, N>

Creates a new call builder for the [identityAt] function.

pub fn isIdentity( &self, identityHash: FixedBytes<32>, ) -> SolCallBuilder<&P, isIdentityCall, N>

Creates a new call builder for the [isIdentity] function.

pub fn sessionCount( &self, platformHandleKey: FixedBytes<32>, ) -> SolCallBuilder<&P, sessionCountCall, N>

Creates a new call builder for the [sessionCount] function.

pub fn sessionAt( &self, platformHandleKey: FixedBytes<32>, index: U256, ) -> SolCallBuilder<&P, sessionAtCall, N>

Creates a new call builder for the [sessionAt] function.

pub fn isSession(&self, addr: Address) -> SolCallBuilder<&P, isSessionCall, N>

Creates a new call builder for the [isSession] function.

pub fn sessionIdentity( &self, addr: Address, ) -> SolCallBuilder<&P, sessionIdentityCall, N>

Creates a new call builder for the [sessionIdentity] function.

pub fn execute( &self, target: Address, value: U256, data: Bytes, sigs: Vec<Bytes>, ) -> SolCallBuilder<&P, executeCall, N>

Creates a new call builder for the [execute] function.

pub fn executeBatch( &self, targets: Vec<Address>, values: Vec<U256>, datas: Vec<Bytes>, sigs: Vec<Bytes>, ) -> SolCallBuilder<&P, executeBatchCall, N>

Creates a new call builder for the [executeBatch] function.

pub fn upgradeToLatest(&self) -> SolCallBuilder<&P, upgradeToLatestCall, N>

Creates a new call builder for the [upgradeToLatest] function.

pub fn setThreshold( &self, newThreshold: u8, ) -> SolCallBuilder<&P, setThresholdCall, N>

Creates a new call builder for the [setThreshold] function.

Source

impl<P: Provider<N>, N: Network> WebWalletInstance<P, N>

Event filters.

pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.

pub fn SessionRegistered_filter(&self) -> Event<&P, SessionRegistered, N>

Creates a new event filter for the SessionRegistered event.

pub fn SessionRevoked_filter(&self) -> Event<&P, SessionRevoked, N>

Creates a new event filter for the SessionRevoked event.

pub fn Executed_filter(&self) -> Event<&P, Executed, N>

Creates a new event filter for the Executed event.

pub fn NativeReceived_filter(&self) -> Event<&P, NativeReceived, N>

Creates a new event filter for the NativeReceived event.

pub fn NativeSent_filter(&self) -> Event<&P, NativeSent, N>

Creates a new event filter for the NativeSent event.