pub struct verifyProofCall {
pub resource: <ResourceInfo as SolType>::RustType,
pub sender: <SenderInfo as SolType>::RustType,
pub revealedSubsection: Bytes,
pub notaryTlsProof: <NotaryTlsProof as SolType>::RustType,
pub backendSigData: <BackendSig as SolType>::RustType,
pub receiverUserId: String,
}Expand description
Stateless preflight of a TLS-notarized comment proof.
Function with signature verifyProof((string,string,string,string),(string,bytes,bytes),bytes,(bytes,bytes32,bytes32,bytes32,bytes,bytes32,uint256,bytes32[],bytes32[],bytes32[],bytes32[],bytes32[],bytes32[],bytes,bytes32[],bytes,bytes32[],bytes),(bytes,uint256),string) and selector 0x0f6ae884.
function verifyProof(ResourceInfo calldata resource, SenderInfo calldata sender, bytes calldata revealedSubsection, NotaryTlsProof calldata notaryTlsProof, BackendSig calldata backendSigData, string calldata receiverUserId) external view returns (bool);Fields
resource: <ResourceInfo as SolType>::RustTypesender: <SenderInfo as SolType>::RustTyperevealedSubsection: BytesnotaryTlsProof: <NotaryTlsProof as SolType>::RustTypebackendSigData: <BackendSig as SolType>::RustTypereceiverUserId: StringTrait Implementations
Sourceimpl Clone for verifyProofCall
impl Clone for verifyProofCall
Sourcefn clone(&self) -> verifyProofCall
fn clone(&self) -> verifyProofCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for verifyProofCall
impl SolCall for verifyProofCall
Sourceconst SIGNATURE: &'static str = "verifyProof((string,string,string,string),(string,bytes,bytes),bytes,(bytes,bytes32,bytes32,bytes32,bytes,bytes32,uint256,bytes32[],bytes32[],bytes32[],bytes32[],bytes32[],bytes32[],bytes,bytes32[],bytes,bytes32[],bytes),(bytes,uint256),string)"
const SIGNATURE: &'static str = "verifyProof((string,string,string,string),(string,bytes,bytes),bytes,(bytes,bytes32,bytes32,bytes32,bytes,bytes32,uint256,bytes32[],bytes32[],bytes32[],bytes32[],bytes32[],bytes32[],bytes,bytes32[],bytes,bytes32[],bytes),(bytes,uint256),string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (ResourceInfo, SenderInfo, Bytes, NotaryTlsProof, BackendSig, String)
type Parameters<'a> = (ResourceInfo, SenderInfo, Bytes, NotaryTlsProof, BackendSig, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<verifyProofCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<verifyProofCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<verifyProofCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<verifyProofCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.