pub struct bindCall {
pub platformId: FixedBytes<32>,
pub verifierVersion: u16,
pub payload: Bytes,
pub publishName: bool,
}Expand description
The one write. The contract does not know what payload is:
it names a platform and this chain’s verifier version for it,
and the Proof Verifier routes the bytes to the one contract
that decodes them. The value attached must equal quoteBind
for the same pair exactly.
Function with signature bind(bytes32,uint16,bytes,bool) and selector 0x72d3edca.
function bind(bytes32 platformId, uint16 verifierVersion, bytes calldata payload, bool publishName) external payable;Fields
platformId: FixedBytes<32>verifierVersion: u16payload: BytespublishName: boolTrait Implementations
Sourceimpl JsonAbiExt for bindCall
impl JsonAbiExt for bindCall
Sourceimpl SolCall for bindCall
impl SolCall for bindCall
Sourceconst SIGNATURE: &'static str = "bind(bytes32,uint16,bytes,bool)"
const SIGNATURE: &'static str = "bind(bytes32,uint16,bytes,bool)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedBytes<32>, Uint<16>, Bytes, Bool)
type Parameters<'a> = (FixedBytes<32>, Uint<16>, Bytes, Bool)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<bindCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<bindCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = bindReturn
type Return = bindReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<bindCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<bindCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.