pub enum WebWalletEvents {
SessionRegistered(SessionRegistered),
SessionRevoked(SessionRevoked),
Executed(Executed),
NativeReceived(NativeReceived),
NativeSent(NativeSent),
}Expand description
Container for all the WebWallet events.
Variants
SessionRegistered(SessionRegistered)
SessionRevoked(SessionRevoked)
Executed(Executed)
NativeReceived(NativeReceived)
NativeSent(NativeSent)
Implementations
Sourceimpl WebWalletEvents
impl WebWalletEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl WebWalletEvents
impl WebWalletEvents
Sourcepub fn session_registered(
platform: String,
handle: String,
session_addr: Address,
) -> Self
pub fn session_registered( platform: String, handle: String, session_addr: Address, ) -> Self
Creates a SessionRegistered event.
event SessionRegistered(string,string,address)Sourcepub fn session_revoked(
platform: String,
handle: String,
session_addr: Address,
) -> Self
pub fn session_revoked( platform: String, handle: String, session_addr: Address, ) -> Self
Creates a SessionRevoked event.
event SessionRevoked(string,string,address)Sourcepub fn executed(target: Address, value: U256, nonce: U256) -> Self
pub fn executed(target: Address, value: U256, nonce: U256) -> Self
Creates a Executed event.
event Executed(address,uint256,uint256)Sourcepub fn native_received(from: Address, amount: U256) -> Self
pub fn native_received(from: Address, amount: U256) -> Self
Creates a NativeReceived event.
event NativeReceived(address,uint256)Sourcepub fn native_sent(to: Address, amount: U256) -> Self
pub fn native_sent(to: Address, amount: U256) -> Self
Creates a NativeSent event.
event NativeSent(address,uint256)Trait Implementations
Sourceimpl Clone for WebWalletEvents
impl Clone for WebWalletEvents
Sourcefn clone(&self) -> WebWalletEvents
fn clone(&self) -> WebWalletEvents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl IntoLogData for WebWalletEvents
impl IntoLogData for WebWalletEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl SolEventInterface for WebWalletEvents
impl SolEventInterface for WebWalletEvents