pub struct WebWalletInstance<P, N = Ethereum> { /* private fields */ }Expand description
A WebWallet instance.
Contains type-safe methods for interacting with an on-chain instance of the
WebWallet contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> WebWalletInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> WebWalletInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain WebWallet contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> WebWalletInstance<&P, N>
impl<P: Clone, N> WebWalletInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> WebWalletInstance<P, N>
pub fn with_cloned_provider(self) -> WebWalletInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> WebWalletInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> WebWalletInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn threshold(&self) -> SolCallBuilder<&P, thresholdCall, N>
pub fn threshold(&self) -> SolCallBuilder<&P, thresholdCall, N>
Creates a new call builder for the [threshold] function.
Sourcepub fn nonce(&self) -> SolCallBuilder<&P, nonceCall, N>
pub fn nonce(&self) -> SolCallBuilder<&P, nonceCall, N>
Creates a new call builder for the [nonce] function.
Sourcepub fn registry(&self) -> SolCallBuilder<&P, registryCall, N>
pub fn registry(&self) -> SolCallBuilder<&P, registryCall, N>
Creates a new call builder for the [registry] function.
Sourcepub fn factory(&self) -> SolCallBuilder<&P, factoryCall, N>
pub fn factory(&self) -> SolCallBuilder<&P, factoryCall, N>
Creates a new call builder for the [factory] function.
Sourcepub fn identityCount(&self) -> SolCallBuilder<&P, identityCountCall, N>
pub fn identityCount(&self) -> SolCallBuilder<&P, identityCountCall, N>
Creates a new call builder for the [identityCount] function.
Sourcepub fn identityAt(&self, index: U256) -> SolCallBuilder<&P, identityAtCall, N>
pub fn identityAt(&self, index: U256) -> SolCallBuilder<&P, identityAtCall, N>
Creates a new call builder for the [identityAt] function.
Sourcepub fn isIdentity(
&self,
identityHash: FixedBytes<32>,
) -> SolCallBuilder<&P, isIdentityCall, N>
pub fn isIdentity( &self, identityHash: FixedBytes<32>, ) -> SolCallBuilder<&P, isIdentityCall, N>
Creates a new call builder for the [isIdentity] function.
Sourcepub fn sessionCount(
&self,
platformHandleKey: FixedBytes<32>,
) -> SolCallBuilder<&P, sessionCountCall, N>
pub fn sessionCount( &self, platformHandleKey: FixedBytes<32>, ) -> SolCallBuilder<&P, sessionCountCall, N>
Creates a new call builder for the [sessionCount] function.
Sourcepub fn sessionAt(
&self,
platformHandleKey: FixedBytes<32>,
index: U256,
) -> SolCallBuilder<&P, sessionAtCall, N>
pub fn sessionAt( &self, platformHandleKey: FixedBytes<32>, index: U256, ) -> SolCallBuilder<&P, sessionAtCall, N>
Creates a new call builder for the [sessionAt] function.
Sourcepub fn isSession(&self, addr: Address) -> SolCallBuilder<&P, isSessionCall, N>
pub fn isSession(&self, addr: Address) -> SolCallBuilder<&P, isSessionCall, N>
Creates a new call builder for the [isSession] function.
Sourcepub fn sessionIdentity(
&self,
addr: Address,
) -> SolCallBuilder<&P, sessionIdentityCall, N>
pub fn sessionIdentity( &self, addr: Address, ) -> SolCallBuilder<&P, sessionIdentityCall, N>
Creates a new call builder for the [sessionIdentity] function.
Sourcepub fn execute(
&self,
target: Address,
value: U256,
data: Bytes,
sigs: Vec<Bytes>,
) -> SolCallBuilder<&P, executeCall, N>
pub fn execute( &self, target: Address, value: U256, data: Bytes, sigs: Vec<Bytes>, ) -> SolCallBuilder<&P, executeCall, N>
Creates a new call builder for the [execute] function.
Sourcepub fn executeBatch(
&self,
targets: Vec<Address>,
values: Vec<U256>,
datas: Vec<Bytes>,
sigs: Vec<Bytes>,
) -> SolCallBuilder<&P, executeBatchCall, N>
pub fn executeBatch( &self, targets: Vec<Address>, values: Vec<U256>, datas: Vec<Bytes>, sigs: Vec<Bytes>, ) -> SolCallBuilder<&P, executeBatchCall, N>
Creates a new call builder for the [executeBatch] function.
Sourcepub fn upgradeToLatest(&self) -> SolCallBuilder<&P, upgradeToLatestCall, N>
pub fn upgradeToLatest(&self) -> SolCallBuilder<&P, upgradeToLatestCall, N>
Creates a new call builder for the [upgradeToLatest] function.
Sourcepub fn setThreshold(
&self,
newThreshold: u8,
) -> SolCallBuilder<&P, setThresholdCall, N>
pub fn setThreshold( &self, newThreshold: u8, ) -> SolCallBuilder<&P, setThresholdCall, N>
Creates a new call builder for the [setThreshold] function.
Sourceimpl<P: Provider<N>, N: Network> WebWalletInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> WebWalletInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn SessionRegistered_filter(&self) -> Event<&P, SessionRegistered, N>
pub fn SessionRegistered_filter(&self) -> Event<&P, SessionRegistered, N>
Creates a new event filter for the SessionRegistered event.
Sourcepub fn SessionRevoked_filter(&self) -> Event<&P, SessionRevoked, N>
pub fn SessionRevoked_filter(&self) -> Event<&P, SessionRevoked, N>
Creates a new event filter for the SessionRevoked event.
Sourcepub fn Executed_filter(&self) -> Event<&P, Executed, N>
pub fn Executed_filter(&self) -> Event<&P, Executed, N>
Creates a new event filter for the Executed event.
Sourcepub fn NativeReceived_filter(&self) -> Event<&P, NativeReceived, N>
pub fn NativeReceived_filter(&self) -> Event<&P, NativeReceived, N>
Creates a new event filter for the NativeReceived event.
Sourcepub fn NativeSent_filter(&self) -> Event<&P, NativeSent, N>
pub fn NativeSent_filter(&self) -> Event<&P, NativeSent, N>
Creates a new event filter for the NativeSent event.